import { createElement } from 'react';

// src/HTML2React/index.ts
var NON_WHITESPACE_CHARACTER = /[^\s]/;
var HTML_SPECIAL_CHAR = /[\s>/]/;
var HTML_ATTRIBUTE_CHAR = /[=\s>/]/;
var VOID_TAGS = /* @__PURE__ */ new Set([
  "area",
  "base",
  "br",
  "col",
  "embed",
  "hr",
  "img",
  "input",
  "link",
  "meta",
  "param",
  "source",
  "track",
  "wbr"
]);
var _isVoidTag = VOID_TAGS.has.bind(VOID_TAGS);
var _handleIndex = (index) => {
  if (index < 0) {
    throw new Error("invalid html");
  }
  return index;
};
var HTML2React = ({
  html,
  components = {},
  attributes = {},
  converters = {},
  processTextSegment
}) => {
  let start = 0;
  const tagsQueue = new Array(1);
  const root = [];
  const childrenQueue = [root];
  const substring = html.substring.bind(html);
  const _indexOf = html.indexOf.bind(html);
  const search = (index, regexp) => index + _handleIndex(substring(index).search(regexp));
  const indexOf = (item, index) => _handleIndex(_indexOf(item, index));
  const handleTextSegment = processTextSegment ? (nodes, start2, end) => {
    let l = nodes.length;
    const segment = processTextSegment(substring(start2, end), () => l++);
    if (Array.isArray(segment)) {
      nodes.push(...segment);
    } else {
      nodes.push(segment);
    }
  } : (nodes, start2, end) => {
    nodes.push(substring(start2, end));
  };
  for (let index = _indexOf("<"), char; index != -1; index = _indexOf("<", index)) {
    const parentChildren = childrenQueue[childrenQueue.length - 1];
    if (start != index) {
      handleTextSegment(parentChildren, start, index);
    }
    char = html[++index];
    if (char == "/") {
      start = ++index;
      index = indexOf(">", index);
      const tag = substring(start, index).trim();
      for (let j = tagsQueue.length; j--; ) {
        if (tagsQueue[j] == tag) {
          tagsQueue.length = j;
          childrenQueue.length = j;
          break;
        }
      }
    } else if (char != "!") {
      start = search(index, NON_WHITESPACE_CHARACTER);
      index = search(start, HTML_SPECIAL_CHAR);
      const tag = substring(start, index);
      const props = {
        key: parentChildren.length
      };
      while (true) {
        index = search(index, NON_WHITESPACE_CHARACTER);
        char = html[index];
        if (char == "/" || char == ">") {
          break;
        }
        start = index;
        index = search(index, HTML_ATTRIBUTE_CHAR);
        char = html[index];
        const htmlKey = substring(start, index);
        const key = htmlKey in attributes ? attributes[htmlKey] : htmlKey;
        let value;
        if (char != "=" && char != "/" && char != ">") {
          index = search(index + 1, NON_WHITESPACE_CHARACTER);
        }
        if (html[index] == "=") {
          index = search(index + 1, NON_WHITESPACE_CHARACTER);
          char = html[index];
          const isWrapped = char == "'" || char == '"';
          const next = isWrapped ? indexOf(char, ++index) : search(index, HTML_SPECIAL_CHAR);
          value = substring(index, next);
          index = next + isWrapped;
        } else {
          value = "true";
        }
        props[key] = key in converters ? converters[key](value, tag) : value;
      }
      if (html[index] == "/") {
        index++;
      }
      if (tag != "script") {
        if (!_isVoidTag(tag)) {
          childrenQueue.push(props.children = []);
          tagsQueue.push(tag);
        }
      } else {
        const str = substring(index + 1);
        const scriptClosingTag = /<\/\s*script\s*>/.exec(str);
        if (scriptClosingTag) {
          const indexOfNextScriptOpenTag = str.search(/<\s*script\s*>/);
          const indexOfScriptClosingTag = scriptClosingTag.index;
          if (indexOfNextScriptOpenTag == -1 || indexOfScriptClosingTag < indexOfNextScriptOpenTag) {
            const code = str.substring(0, indexOfScriptClosingTag);
            if (code) {
              props.dangerouslySetInnerHTML = { __html: code };
            }
            index += indexOfScriptClosingTag + scriptClosingTag[0].length;
          }
        }
      }
      parentChildren.push(
        createElement(tag in components ? components[tag] : tag, props)
      );
    } else if (substring(++index, index + 7) == "DOCTYPE") {
      index = indexOf(">", index + 7);
    } else {
      index = indexOf("-->", index) + 2;
    }
    start = ++index;
  }
  if (start < html.length) {
    handleTextSegment(childrenQueue[childrenQueue.length - 1], start);
  }
  return root.length > 1 ? root : root[0];
};
var HTML2React_default = HTML2React;

export { HTML2React_default };
//# sourceMappingURL=out.js.map
//# sourceMappingURL=chunk-RZHSD4WF.js.map